@@ -1,13 +1,12 @@
-# last modified 2008/05/15 by Ph. Grosjean
-
 ".onLoad" <-
-function(lib, pkg) {
+function (lib, pkg)
+{
     # Starting the DDE server automatically if under Windows
-    # and option use.DDE == TRUE 
+    # and option use.DDE == TRUE
     use.DDE <- getOption("use.DDE")
     if (.Platform$OS.type == "windows" && !is.null(use.DDE) && use.DDE)
         guiDDEInstall()
-    
+
     # If an IDE is defined, start it now
     IDE <- getOption("IDE")
     if (!is.null(IDE) && file.exists(IDE))
@@ -19,5 +18,3 @@ function(lib, pkg) {
 if (.Platform$OS.type != "windows")
     "writeClipboard" <- function (str, format = 1)
         stop("Not implemented yet on other platforms than Windows")
-
-
